@@ -3,19 +3,19 @@
 
 #include "mostQtHeaders.h"
 
-class BibTeXFileInfo{
+class BibTeXFileInfo
+{
 public:
 	//these are the properties of the file when it was loaded the last time (no watching)
 	QTextCodec *codec;
 	QDateTime lastModified;
 	QSet<QString> ids;
 	QString linksTo;
-	bool loadIfModified(const QFileInfo& fi);
+	bool loadIfModified(const QFileInfo &fi);
 private:
-	void load(const QFileInfo& fi);
+	void load(const QFileInfo &fi);
 protected: //unit tests access this
-	void parse(QByteArray& data);
+	void parse(QByteArray &data);
 };
 
-
 #endif // BIBTEXPARSER_H
