@@ -610,10 +610,10 @@ void QFormatConfig::showEvent(QShowEvent *e){
 	setCurrentScheme(m_schemes.first());
 }
 
-void QFormatConfig::on_m_selector_currentIndexChanged(int idx)
+void QFormatConfig::on_m_selector_currentIndexChanged(int)
 {
 	return; //not needed in txs
-	
+	/*
 	QList<int> hasModif = modifiedFormats();
 
 	if ( hasModif.count() )
@@ -636,7 +636,7 @@ void QFormatConfig::on_m_selector_currentIndexChanged(int idx)
 
 	m_currentScheme = idx >= 0 && idx < m_schemes.count() ? m_schemes.at(idx) : 0;
 
-	cancel();
+	cancel();*/
 }
 
 /*! @} */
