@@ -15,11 +15,12 @@
 class PreviewWidget : public QScrollArea
 {
 	Q_OBJECT
-public:
-	explicit PreviewWidget(QWidget * parent = 0);
 
-public slots:	
-	void previewLatex(const QPixmap& previewImage);
+public:
+	explicit PreviewWidget(QWidget *parent = 0);
+
+public slots:
+	void previewLatex(const QPixmap &previewImage);
 	void fitImage(bool fit);
 	void centerImage(bool center);
 	void scaleImage(double factor);
@@ -38,29 +39,32 @@ private:
 	bool mFit;
 };
 
-class OutputViewWidget: public TitledPanel {
+class OutputViewWidget: public TitledPanel
+{
 	Q_OBJECT
+
 public:
-	explicit OutputViewWidget(QWidget * parent = 0);
+	explicit OutputViewWidget(QWidget *parent = 0);
 
 	const QString MESSAGES_PAGE;
 	const QString LOG_PAGE;
 	const QString PREVIEW_PAGE;
 	const QString SEARCH_RESULT_PAGE;
 
-	LatexLogWidget* getLogWidget() {return logWidget;}
-	SearchResultWidget* getSearchResultWidget() {return searchResultWidget;}
+	LatexLogWidget *getLogWidget() { return logWidget; }
+	SearchResultWidget *getSearchResultWidget() { return searchResultWidget; }
 	bool isPreviewPanelVisible();
 	void setMessage(const QString &message); //set the message text (don't change page and no auto-show)
 	bool childHasFocus();
 
 	virtual void changeEvent(QEvent *event);
+
 public slots:
 	void copy();
-	void resetMessages(bool noTabChange=false); //remove all messages and jumps to the message page (stays hidden if not visible)
-	void resetMessagesAndLog(bool noTabChange=false);
-	void selectLogEntry(int logEntryNumber, bool makeVisible=true);
-	void previewLatex(const QPixmap& pixmap);
+	void resetMessages(bool noTabChange = false); //remove all messages and jumps to the message page (stays hidden if not visible)
+	void resetMessagesAndLog(bool noTabChange = false);
+	void selectLogEntry(int logEntryNumber, bool makeVisible = true);
+	void previewLatex(const QPixmap &pixmap);
 
 	void insertMessageLine(const QString &message); //inserts the message text (don't change page and no auto-show)
 
@@ -71,59 +75,65 @@ private:
 	LatexLogWidget *logWidget;
 	SearchResultWidget *searchResultWidget;
 	LogEditor *OutputMessages;
-	
+
 	void retranslateUi();
 };
 
 
-class CustomWidgetList: public QDockWidget{
+class CustomWidgetList: public QDockWidget
+{
 	Q_OBJECT
+
 public:
-	CustomWidgetList(QWidget *p=0);
-	void addWidget(QWidget* widget, const QString& id, const QString& text, const QString& iconName);
-	void setWidgetText(const QString& id, const QString& text);
-	void setWidgetText(QWidget* widget, const QString& text);
-	void setWidgetIcon(const QString& id, const QString& icon);
-	void setWidgetIcon(QWidget* widget, const QString& icon);
+	CustomWidgetList(QWidget *p = 0);
+	void addWidget(QWidget *widget, const QString &id, const QString &text, const QString &iconName);
+	void setWidgetText(const QString &id, const QString &text);
+	void setWidgetText(QWidget *widget, const QString &text);
+	void setWidgetIcon(const QString &id, const QString &icon);
+	void setWidgetIcon(QWidget *widget, const QString &icon);
 	int widgetCount() const;
-	void setHiddenWidgets(const QString& hidden); 
-	QString hiddenWidgets() const; 
-	QWidget* widget(int i) const;
-	QWidget* widget(const QString& id) const;
-    QList<QWidget*> getWidgets() const;
-	void setCurrentWidget(QWidget* widget);
-	QWidget* currentWidget() const;
+	void setHiddenWidgets(const QString &hidden);
+	QString hiddenWidgets() const;
+	QWidget *widget(int i) const;
+	QWidget *widget(const QString &id) const;
+	QList<QWidget *> getWidgets() const;
+	void setCurrentWidget(QWidget *widget);
+	QWidget *currentWidget() const;
 	bool isNewLayoutStyleEnabled() const;
+
 signals:
-	void widgetContextMenuRequested(QWidget* widget, const QPoint& globalPosition);
+	void widgetContextMenuRequested(QWidget *widget, const QPoint &globalPosition);
+
 public slots:
 	void showWidgets(bool newLayoutStyle);
 	void setToolbarIconSize(int sz);
+
 private slots:
 	void showPageFromAction();
 	void currentWidgetChanged(int i);
 	void toggleWidgetFromAction(bool on);
-	void customContextMenuRequested(const QPoint& localPosition);	
+	void customContextMenuRequested(const QPoint &localPosition);
+
 private:
-	void showWidget(const QString& id);
-	void hideWidget(const QString& id);
+	void showWidget(const QString &id);
+	void hideWidget(const QString &id);
 	//void addWidgetOld(QWidget* widget, const QString& id, const QString& text, const QString& iconName, const bool visible);
 //	void addWidgetNew(QWidget* widget, const QString& id, const QString& text, const QString& iconName, const bool visible);
-	QString widgetId(QWidget* widget) const;
-	
-	
+	QString widgetId(QWidget *widget) const;
+
+
 	QStringList hiddenWidgetsIds;
-	QList<QWidget*> widgets;
+	QList<QWidget *> widgets;
 	bool newStyle;
-	
+
 	//old layout
 	QToolBox *toolbox;
-		
+
 	//new layout
-	QFrame* frame;
-	QStackedWidget* stack;
-	QToolBar* toolbar;
-		
+	QFrame *frame;
+	QStackedWidget *stack;
+	QToolBar *toolbar;
+
 };
 
-#endif 
+#endif
